yakumo.cinder.v2.volume_type.Manager

Package yakumo :: Package cinder :: Package v2 :: Module volume_type :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

manager class for volume types on Block Storage V2 API

Nested Classes | [hide private]
| resource_class resource class for volume types on Block Storage V2 API

Instance Methods | [hide private]
yakumo.cinder.v2.volume_type.Resource |
create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, metadata=`'``__UNDEF__``'`, is_public=`'``__UNDEF__``'`) Register a volume type | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``volume``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``volume_type``'``
| _json_resources_key = ``'``volume_types``'``
| _url_resource_list_path = ``'``/types``'``
| _url_resource_path = ``'``/types``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, metadata=`'``__UNDEF__``'`, is_public=`'``__UNDEF__``'`) | source code
Register a volume type Parameters: `name` (str) - Volume type name `description` (str) - Description `metadata` (dict) - Metadata (key=value) `is_public` (bool) - Whether volume type is public Returns: yakumo.cinder.v2.volume_type.Resource Created volume type Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('metadata', 'extra_specs', mapper.N
      oop), ('is_public', 'is_public', mapper.Noop),]